#!/usr/bin/env python
# -*- coding: utf-8 -*-
import logging

__version__ = '0.0.3'

try:
    from thumbor_text_filter.text import Filter  # NOQA
except ImportError:
    logging.exception('Could not import thumbor_text_filter. Probably due to setup.py installing it.')


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
from thumbor_text_filter import __version__

tests_require = [
    'mock',
    'nose',
    'coverage',
    'yanc',
    'colorama',
    'preggy',
    'ipdb',
    'coveralls',
    'numpy',
]

setup(
    name='thumbor_text_filter',
    version=__version__,
    description='Text filter for thumbor.',
    long_description='''
Text filter for thumbor.
''',
    keywords='thumbor filter',
    author='Wongnai.com',
    author_email='tanapoln@wongnai.com',
    url='',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: MacOS',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
    ],
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'pillow',
    ],
    extras_require={
        'tests': tests_require,
    }
)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from PIL import ImageDraw
from PIL import ImageFont
from thumbor.filters import BaseFilter, filter_method

import logging

class Filter(BaseFilter):
    @filter_method(
        BaseFilter.String,#word
        BaseFilter.PositiveNumber,#posX
        BaseFilter.PositiveNumber,#posY
        BaseFilter.String,#color name see: http://pillow.readthedocs.io/en/4.0.x/reference/ImageColor.html#color-names
        BaseFilter.PositiveNumber, #font-size
        BaseFilter.String, #font-family
    )
    def text(self, word, x, y, color, font_size, font_family="Tahoma"):
        try:
            image = self.engine.image
            usr_font = ImageFont.truetype(font_family, font_size)
            drawer = ImageDraw.Draw(image)
            drawer.text((x, y), word, fill=color, font=usr_font)
            self.engine.image = image
        except IOError:
            logging.error("Cannot find font:" + font_family)
            pass